@@ -8,9 +8,7 @@ Module to find the SQS queues in lookup
 
 import re
 
-from botocore.exceptions import ClientError
-
-from ecs_composex.common import LOG, keyisset
+from ecs_composex.common import LOG
 from ecs_composex.common.aws import (
     define_lookup_role_from_info,
     find_aws_resource_arn_from_tags_api,
